@@ -200,18 +200,16 @@ static char *preInitCmd =
 		"}\n"
 	"}\n"
 #endif /* KIT_STORAGE_CVFS */
-#ifndef TCLKIT_DLL
 	"if {![info exists s]} {\n"
 		"set s \"\"\n"
 	"}\n"
-#endif /* !TCLKIT_DLL */
 #ifdef TCLKIT_DLL
 	"set ::TCLKIT_TYPE \"kitdll\"\n"
 #else
 	"set ::TCLKIT_TYPE \"tclkit\"\n"
 #endif /* TCLKIT_DLL */
 	"set ::TCLKIT_MOUNTPOINT " TCLKIT_MOUNTPOINT "\n"
-	"set ::TCLKIT_VFSSOURCE " TCLKIT_VFSSOURCE "\n"
+	"catch { set ::TCLKIT_VFSSOURCE " TCLKIT_VFSSOURCE " }\n"
 	"set ::TCLKIT_MOUNTPOINT_VAR {" TCLKIT_MOUNTPOINT "}\n"
 	"set ::TCLKIT_VFSSOURCE_VAR {" TCLKIT_VFSSOURCE "}\n"
 	"uplevel #0 $s\n"
@@ -229,12 +227,12 @@ static char *preInitCmd =
 "tclKitInit";
 
 static const char initScript[] =
-"if {[file isfile [file join [info nameofexe] main.tcl]]} {\n"
+"if {[file isfile [file join " TCLKIT_VFSSOURCE " main.tcl]]} {\n"
 	"if {[info commands console] != {}} { console hide }\n"
 	"set tcl_interactive 0\n"
 	"incr argc\n"
 	"set argv [linsert $argv 0 $argv0]\n"
-	"set argv0 [file join [info nameofexe] main.tcl]\n"
+	"set argv0 [file join " TCLKIT_VFSSOURCE " main.tcl]\n"
 "} else continue\n";
 
 /* SetExecName --
@@ -573,9 +571,27 @@ void __attribute__((constructor)) _Tclkit_Init(void) {
 #else
 static void _Tclkit_Init(void) {
 #endif
+	static int called = 0;
+
+	if (called) {
+		return;
+	}
+
+	called = 1;
+
 	Tcl_StaticPackage(0, "tclkit::init", Tclkit_init_Init, NULL);
 
 	_Tclkit_Generic_Init();
 
 	return;
 }
+
+#if defined(TCLKIT_DLL) && defined(TCLKIT_DLL_STATIC)
+int Tcl_InitReal(Tcl_Interp *interp);
+
+int Tcl_Init(Tcl_Interp *interp) {
+	_Tclkit_Init();
+
+	return(Tcl_InitReal(interp));
+}
+#endif
