@@ -11,9 +11,10 @@ if [ -z "${TCLVERS}" ]; then
 	exit 1
 fi
 
-THREADVERS="2.6.5"
+THREADVERS="2.7.2"
 SRC="src/thread-${THREADVERS}.tar.gz"
 SRCURL="http://sourceforge.net/projects/tcl/files/Thread%20Extension/${THREADVERS}/thread${THREADVERS}.tar.gz/download"
+SRCHASH='-'
 BUILDDIR="$(pwd)/build/thread${THREADVERS}"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
@@ -58,9 +59,7 @@ if [ ! -f "${SRC}" ]; then
 	mkdir 'src' >/dev/null 2>/dev/null
 
 	if [ ! -d 'buildsrc' ]; then
-		rm -f "${SRC}.tmp"
-		wget -O "${SRC}.tmp" "${SRCURL}" || exit 1
-		mv "${SRC}.tmp" "${SRC}"
+		download "${SRCURL}" "${SRC}" "${SRCHASH}" || exit 1
 	fi
 fi
 
